@@ -57,7 +57,26 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
+our %_attribute_min_occurs = (
+    CashBackInfo => 0,
+    IncrementalBid => 1,
+    Param1 => 0,
+    Param2 => 0,
+    Param3 => 0,
+    SegmentId => 1,
+    SegmentParam1 => 0,
+    SegmentParam2 => 0,
+);
+
+sub _attribute_min_occurs {
+    my ($self, $attribute) = @_;
+    if (exists $_attribute_min_occurs{$attribute}) {
+        return $_attribute_min_occurs{$attribute};
+    }
+    return $self->SUPER::_attribute_min_occurs($attribute);
+}
+
+__PACKAGE__->mk_accessors(@_attributes);
 
 1;
 
