@@ -59,7 +59,25 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
+our %_attribute_min_occurs = (
+    AccountFinancialStatus => 1,
+    AccountId => 1,
+    AccountNumber => 0,
+    BalanceAmount => 1,
+    CreditCardLastFour => 0,
+    CreditCardTypeName => 0,
+    PreferredCurrencyCode => 0,
+);
+
+sub _attribute_min_occurs {
+    my ($self, $attribute) = @_;
+    if (exists $_attribute_min_occurs{$attribute}) {
+        return $_attribute_min_occurs{$attribute};
+    }
+    return $self->SUPER::_attribute_min_occurs($attribute);
+}
+
+__PACKAGE__->mk_accessors(@_attributes);
 
 1;
 
